#!/usr/bin/python
################################################################################
#	BdsTestImport.py	Test import system
#				T.Barnaby,	BEAM Ltd,	2009-11-18
################################################################################
#
import os
import sys
import re
import getopt
from datetime import *
from string import *

os.environ["PATH"] = os.environ["PATH"] + ":../bdsImport";

class Config:
	def __init__(s):
		s.hostName = "localhost"
		s.userPassword = "testAdmin:beam00";
		s.inputDir = "input";
		s.network = "TT";
		s.array = "TST";
		s.startTime = datetime(1, 1, 1);
		s.endTime = datetime(1, 1, 1);
		s.channels = [];
		s.createFileFlags = "";
		s.importFileFlags = "";
		

def testImportBdrsFile(config):
	print "Import BDRS: " + config.startTime.isoformat() + " - " + config.endTime.isoformat();
	createCommand = "./bdsTestCreateData -format BDRS -channels " + join(config.channels, ",") + " " + config.createFileFlags;
	importCommand = "bdsImportData -host " + config.hostName + " -user " + config.userPassword + " -format BDRS -network " + config.network + " -array " + config.array + " -channels " + join(config.channels, ",");
	importCommand += " " + config.importFileFlags;

	startTimeStr = config.startTime.strftime("%Y%j_%H%M%S");

	print "Run: " + createCommand + " -startTime " + config.startTime.isoformat() + " -endTime " + config.endTime.isoformat() + " Test1"
	os.system(createCommand + " -startTime " + config.startTime.isoformat() + " -endTime " + config.endTime.isoformat() + " Test1");
	if(os.system(importCommand + " input/" + startTimeStr + ".bdrs")):
		return 1;

	os.remove("input/" + startTimeStr + ".bdrs");
	return 0;
		
def testImportBdrs(config):
	print "TestImportBdrs";
	
	config.network = "BN";
	config.array = "YKA";
	
	for i in range(0, 5):
		config.channels.append("YKB%d:SHZ" % i);
	for i in range(6, 10):
		config.channels.append("YKB%d:SHZ" % i);
	for i in range(1, 10):
		config.channels.append("YKR%d:SHZ" % i);
	config.channels.append("YKW1:BHZ");
	config.channels.append("YKW2:BHZ");

	# BDRS day files
	day = 0;
	config.startTime = date(1993, 1, 1) + timedelta(day);
	config.endTime = config.startTime + timedelta(1);

	if(testImportBdrsFile(config)):
		return 1;

	return 0;

def testImport(config):
	print "TestImport";
	err = testImportBdrs(config);
	if(err):
		return err;
	

def usage():
	print "Usage: bdsTestImport --host <bdshost> --user <user:password>";
	sys.exit(1);

def main():
	config = Config();

	try:
		opts, args = getopt.getopt(sys.argv[1:], "h", ["host=", "user="]);
	except getopt.GetoptError:
        	# print help information and exit:
        	usage();
        	sys.exit(1);

	for o in opts:
		if(o[0] == "-h"):
			usage();
		elif(o[0] == "--host"):
			config.hostName = o[1];
		elif(o[0] == "--user"):
			config.userPassword = o[1];
		else:
			usage();

	if(len(args) != 0):
		usage();

	testImport(config);

	sys.exit(0);

if __name__ == "__main__":
	main();
